@@ -8,6 +8,7 @@ from deepdriver.sdk import util
 from deepdriver import logger
 import deepdriver.version as version
 from deepdriver.sdk.data_types.artifactInfo import ArtifactInfo
+from deepdriver.sdk.data_types.uploadInfo import UploadInfo
 from deepdriver.sdk.interface.file_upload import Progress
 from deepdriver.sdk.security.crypto import Aes
 from deepdriver.sdk.interface.grpc_interface_pb2 import ArtifactEntry
@@ -19,7 +20,7 @@ URL_CREATE = "/api/client/experiment/create"
 URL_CREATE_HPO = "/api/client/experiment/create/hpo"
 URL_GET_HPO = "/api/client/experiment/get/hpo"
 URL_UPLOAD_LOG = "/api/client/run/log/upload"
-URL_UPLOAD_FILE = "/api/client/file/upload"
+URL_UPLOAD_FILE = "/res/file/upload"
 URL_SEND_ALERT = "/api/client/run/alert/send"
 URL_UPDATE_CONFIG = "/api/client/run/config/update"
 URL_FINISH = "/api/client/run/finish"
@@ -62,14 +63,14 @@ def login(http_host: str , api_key: str, id: str, pw: str) -> Dict:
         data = {
             "email": id
         }
-        url = parse_result_wraaper(http_host, URL_CHECK_EMAIL)
+        url = parse_result_wraaper(http_host, get_use_https(),  URL_CHECK_EMAIL)
         rsp = post(url, data)
         if rsp["result"] == "success":
             encKey = rsp["encKey"]
             cipher= Aes(encKey)
             encrypt_pw = cipher.aes_encrypt('pkcs5', pw, 'ECB',None)
 
-            url = parse_result_wraaper(http_host, URL_ID_LOGIN)
+            url = parse_result_wraaper(http_host,  get_use_https(),URL_ID_LOGIN)
             data = {
                 "email": id,
                 "password": encrypt_pw,
@@ -86,7 +87,7 @@ def login(http_host: str , api_key: str, id: str, pw: str) -> Dict:
         data = {
             "key": api_key
         }
-        url = parse_result_wraaper(http_host,URL_API_LOGIN)
+        url = parse_result_wraaper(http_host, get_use_https(),URL_API_LOGIN)
         rsp = post(url, data)
         #logger.debug("login() " + rsp["message"])
         if rsp["result"] == "success":
@@ -118,7 +119,7 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
         "createRun": "Y",
     }
 
-    url = parse_result_wraaper(http_host,URL_CREATE)
+    url = parse_result_wraaper(http_host,  get_use_https(), URL_CREATE)
     rsp = post(url, data)
     logger.debug("init() response : " + rsp["message"])
     return rsp
@@ -138,7 +139,7 @@ def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: D
             "hostname": util.get_hostname(),
         },
     }
-    url = parse_result_wraaper(http_host,URL_CREATE_HPO)
+    url = parse_result_wraaper(http_host, get_use_https(), URL_CREATE_HPO)
     rsp = post(url, data)
     logger.debug("create_hpo() response : " + rsp["message"])
     return rsp
@@ -149,7 +150,7 @@ def get_hpo(http_host:str, exp_name: str="", team_name: str="") -> Dict:
         "teamName": team_name,
         "expName": exp_name,
     }
-    url = parse_result_wraaper(http_host,URL_GET_HPO)
+    url = parse_result_wraaper(http_host, get_use_https(), URL_GET_HPO)
     rsp = post(url, data)
     logger.debug("get_hpo() response : " + rsp["message"])
     return rsp
@@ -163,24 +164,25 @@ def upload_log(http_host:str, run_id: int , exp_name: str, team_name: str , step
         "step" : step,
         "items" :item_list,
     }
-    url = parse_result_wraaper(http_host,URL_UPLOAD_LOG)
+    url = parse_result_wraaper(http_host, get_use_https(), URL_UPLOAD_LOG)
     rsp = post(url, data)
     logger.debug("upload_log() response : " + rsp["message"])
     return rsp
 
 def upload_file(http_host:str, upload_type: str, local_path: str, root_path: str, path: str, run_id: int,
                  teamName: str, expName: str, run_name: str,
-                entry_digest: str, arti_info: ArtifactInfo, file_index: int) -> Dict:
-    url = parse_result_wraaper(http_host, URL_UPLOAD_FILE)
-    with open(path, "rb") as f:
-        progress = Progress(f,)
+                entry_digest: str, arti_info: ArtifactInfo, chunk_size:int, file_index: int) -> Dict:
+    uplod_info =UploadInfo(upload_type=upload_type, local_path=local_path,root_path=root_path,path=path,run_id=run_id,teamName=teamName,expName=expName,run_name=run_name,entry_digest=entry_digest,file_index=file_index)
+    url = parse_result_wraaper(http_host, get_use_https(),URL_UPLOAD_FILE) #TO-DO:
+    with open(local_path, "rb") as f:
+        progress = Progress(f,chunk_size,uplod_info,arti_info)
         for chunk in progress:
             chunk_data = chunk
             rsp=  post(
                 url, data=chunk_data
             )
             logger.debug("upload_file() response : " + rsp["message"])
-
+    logger.debug("upload_file() response : " + rsp["message"])
     return rsp
 
 def update_config(http_host:str, run_id: int , exp_name: str, team_name: str , items: list):
@@ -191,19 +193,19 @@ def update_config(http_host:str, run_id: int , exp_name: str, team_name: str , i
         "runId" : run_id,
         "items" : item_list,
     }
-    url = parse_result_wraaper(http_host,URL_UPDATE_CONFIG)
+    url = parse_result_wraaper(http_host, get_use_https(),URL_UPDATE_CONFIG)
     rsp = post(url, data)
     logger.debug("update_config() response : " + rsp["message"])
     return rsp
 
 def send_alert(http_host:str, data: Dict ) -> Dict:
-    url = parse_result_wraaper(http_host,URL_SEND_ALERT)
+    url = parse_result_wraaper(http_host,get_use_https(),URL_SEND_ALERT)
     rsp = post(url, data)
     logger.debug("send_alert() response : " + rsp["result"])
     return rsp
 
 def finish(http_host: str ,data: Dict) -> Dict:
-    url = parse_result_wraaper(http_host,URL_FINISH)
+    url = parse_result_wraaper(http_host,get_use_https(),URL_FINISH)
     rsp = post(url, data)
     logger.debug("finish() " + rsp["message"])
     return rsp
@@ -233,8 +235,8 @@ def post(url: str, data: Dict) -> Dict:
                 raise Exception(f"request.post() failed({rsp.text if rsp.text else rsp.status_code})", rsp)
     return dict(json.loads(rsp.text))
 
-def parse_result_wraaper(http_host, path):
-    if get_use_https():
+def parse_result_wraaper(http_host, https, path):
+    if https:
         scheme = "https"
     else:
         scheme = "http"
