@@ -26,6 +26,7 @@ use_grpc_tls : bool = False # GPRC의 tls(ssl) 사용여부
 use_https : bool = False
 cert_path: str = None
 http_host : str = None
+CHUNK_SIZE =  1024 * 1024  # 4MB
 
 def set_stub(stub_: ResourceStub) -> None:
     global stub
@@ -186,11 +187,11 @@ def upload_log(run_id: int, team_name: str, exp_name: str, log_step: int, item_d
 
 
 
-CHUNK_SIZE = 4* 1024 * 1024  # 8MB
+
 
 
 def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int,team_name: str, exp_name: str, run_name: str,
-             entry_digest: str, arti_info:ArtifactInfo,
+             entry_digest: str, arti_info:ArtifactInfo, chunk_size: int,
               file_index: int) -> UploadFileRequest:
     if sys.platform.startswith('win32'):
         # 윈도우인 경우 Path Seperator를 리눅스 형식으로 강제로 변경함
@@ -225,7 +226,7 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
         total_size = os.stat(local_path).st_size
         while True:
 
-            chunk_bytes = file.read(CHUNK_SIZE)
+            chunk_bytes = file.read(chunk_size)
             uploaded_size += len(chunk_bytes)
             util.print_progress(uploaded_size, total_size, f'Uploading: [{local_path}]',
                                 f"[{file_index + 1}/{1 if len(arti_info.entry_list) == 0 else len(arti_info.entry_list)}")
@@ -262,11 +263,12 @@ def upload_file(upload_type: str, local_path: str, root_path: str, path: str, ru
     if get_use_grpc():
         rsp: UploadFileResponse = get_stub().upload_file(
             load_file(upload_type, local_path, root_path, path, run_id, teamName, expName,
-                      run_name,  entry_digest, arti_info, file_index))
+                      run_name,  entry_digest, arti_info, CHUNK_SIZE, file_index))
+        return rsp.rsp_result.result == "success"
     else:
-        http_interface.upload_file(upload_type, local_path, root_path, path, run_id, teamName, expName,
-                      run_name,  entry_digest, arti_info, file_index)
-    return rsp.rsp_result.result == "success"
+        rsp =http_interface.upload_file(get_grpc_host(),upload_type, local_path, root_path, path, run_id, teamName, expName,
+                      run_name,  entry_digest, arti_info, CHUNK_SIZE, file_index)
+        return rsp["result"] == "success"
 
 
 def save_file(file_path: str, file_index: int, total_file_count: int, file_size: int, rsps) -> None:
